# Arthexis Constellation

## Purpose
Arthexis Constellation is a narrative-driven Django-based suite that centralizes tools for managing charging infrastructure and orchestrating energy related products and services.

## Features
- Compatible with OCPP 1.6+ chargers
- API integration with Odoo 1.6+
- Runs on Windows and Linux (Ubuntu 16+)
- One codebase. Six* specialized Roles.

## Support
Contact us at tecnologia at gelectriic dot com or visit our [web page](https://www.gelectriic.com/) for professional services and commercial support.

## About Me
> "What, you wanna know about me too? Well, I enjoy developing software, role-playing games, long walks on the beach and a fourth secret thing."
> --Arthexis

